#include <avr/io.h>
#include <util/delay.h>
#include "TWI_driver.h"
#include "logos.h"
#define RESET PC2
#define CLR_RESET PORTC &= ~(1<<RESET)
#define SET_RESET PORTC |=  (1<<RESET)

typedef uint8_t bitmap_t[4][132];

void sendcommand(unsigned char payload)
{
	Send_start();			//send start strings
	Send_byte(OWN_ADR);		//Slave address
	Send_byte(0x00);		//Control Byte - Command
	Send_byte(payload);		//payload
	Send_stop();
}

void senddata(unsigned char payload)
{
	Send_start();			//send start strings
	Send_byte(OWN_ADR);		//Slave address
	Send_byte(0x40);		//Control Byte - Data (non-continued)
	Send_byte(payload);		//payload
	Send_stop();
}

void show_bitmap(unsigned char bitmap)
{
	for(unsigned char i=0;i<4;i++)
	{
		sendcommand(0x00);		//lower column address
		sendcommand(0x10);		//upper column address
		sendcommand(0xB0+i);	//set page address
		for(unsigned char j=0;j<128;j++)
		{
			if(bitmap==0)
			{
				senddata(logo1[i][j]);
			}
			else
			{
				senddata(logo2[i][j]);
			}
		}
	}
}

void lcd_init(void)
{
	CLR_RESET;
	SET_RESET;
	sendcommand(0xAE); // Set Display Off

	sendcommand(0xA8); // Set MUX Ratio
	sendcommand(0x3F); // 64 MUX

	sendcommand(0xA1); // Set Segment Re-map (0xa0 normal,0xa1 reverse)

	sendcommand(0xC0); // Set COM Output Scan Direction (0xc0 normal,0xc8 reverse)

	sendcommand(0x20); // Set Memory Addressing Mode
	sendcommand(0x00); // Horizontal

	sendcommand(0x81); // set contrast control
	sendcommand(0x40); // second byte

	sendcommand(0xAF); // Set Display ON
}

int main(void)
{
	PORTD = 0xFF;		// all off
	DDRD = 0x00;	// VPP output
	PORTC = 0b11011110;
	DDRC = 0xFE;
	//DDRD |= 0x06;	// led pins output
	lcd_init();
	// enable VPP
	//PORTD |= (1<<3);
	while (1)
	{
		show_bitmap(0);
		_delay_ms(4000);
		show_bitmap(1);
		_delay_ms(4000);
	}
	return 0;
}
